/*******************************************************\
* irmp3-ncurses - An ncurses frontend for irmp3 using   *
* the Network Control Module                            *
* (C) 2005 Ross Axe                                     *
*                                                       *
* poll-wthread.c - I/O polling using Windows threads    *
\*******************************************************/

#if HAVE_CONFIG_H
#  include "config.h"
#endif

#include <windows.h>

#include "irmp3-ncurses.h"

vcid("$Id: poll-wthread.c,v 1.5 2005/12/30 13:18:48 ross Exp $");



HANDLE hsock_thread;

void block_net(void)
{
    return;
}

void unblock_net(void)
{
    return;
}


static DWORD WINAPI sock_thread(void *param)
{
    int const sock = (int)param;

    for(;;) {
	if(!handle_net(sock)) {
	    sbar_printf(_("Server shutdown"));
	    return 0;
	}
    }
}

int main_poll_loop(int sock)
{
    hsock_thread = CreateThread(NULL, 0, sock_thread, (void *)sock, 0, NULL);
    while(key_callback(sock, getch()));
    TerminateThread(hsock_thread, 0);
    return 0;
}
